@@ -278,8 +278,12 @@ class HuaweiCloudProvider(Provider):
                 delete_volume=True,
                 delete_publicip=True
             )
-            response = self.ecs_client.delete_servers(request)
-            print(response)
+            try:
+                response = self.ecs_client.delete_servers(request)
+                print(response)
+            except exceptions.ClientRequestException as ex:
+                if ex.status_code == 404:
+                    continue
 
 
 class ManagedProvider(Provider):
@@ -293,3 +297,6 @@ class ManagedProvider(Provider):
             # TODO: 以key方式登录target并注入oos秘钥
             if self.password:
                 self._setup_sshpass(self.ip, self.password)
+            else:
+                print("Warning: -p/--password is not provided. Unable to sync "
+                "key-pair to the target Machines. Please do the sync step by hand.")
