@@ -95,3 +95,6 @@ if not CONFIG:
     raise click.ClickException("Unable to locate config file")
 if not KEY_DIR:
     raise click.ClickException("Unable to locate key pair file")
+
+# Make sure ssh key file works with right permission.
+os.chmod(os.path.join(KEY_DIR, 'id_rsa'), 0o400)
